==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_eu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=eu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'Dokumentu bat erantsi',
	'bouton_ajouter_image' => 'Irudi bat erantsi',
	'bouton_ajouter_image_document' => 'Irudi bat edo dokumentu bat erantsi',

	// D
	'double_clic_inserer_doc' => 'klik bikoitzaren bidez lasterbidea testoan txertatzen ahal duzu',

	// E
	'entree_dimensions' => 'Dimentsioak',
	'entree_titre_document' => 'Agiriaren izenburua :',
	'entree_titre_image' => 'Irudiaren izenburua :',

	// I
	'image_tourner_180' => '180 graduko errotazioa',
	'image_tourner_droite' => '90 graduko errotazioa eskuinera',
	'image_tourner_gauche' => '90 graduko errotazioa ezkerrera',
	'info_document' => 'Dokumentua',
	'info_document_indisponible' => 'Dokumentu hau ez da erabilgarria',
	'info_documents' => 'Dokumentuak',
	'info_inclusion_directe' => 'Zuzeneko inklusioa:',
	'info_inclusion_vignette' => 'Miniaturaren inklusioa :',
	'info_installer_tous_documents' => 'Dokumentu guztiak instalatu',
	'info_logo_max_taille' => 'Logoek @maxi@ baino gutxiago neurtu behar dure derrigorrez (artxiboak @actuel@ neurtzen du).',
	'info_portfolio' => 'Album-orrialdea',
	'info_referencer_doc_distant' => 'Dokumentu bat interneten erreferentziatu :',
	'info_telecharger' => 'Zure ordenagailutik igo :',
	'item_autoriser_selectionner_date_en_ligne' => 'dokumentu bakotxaren data aldatzea baimendu',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Dokumentuen data da gunean noiz gehituak izan diren data',

	// T
	'texte_documents_joints' => 'Dokumentuak(fitxategi bulegotikak, irudiak, multimedia, etab.) artikuluetara eta/edo ataletara gehitzea baimendu ahal duzu. Gero fitxategi hauek artikuluan erreferientziatuak izaten ahalko dira, edo bananduta bistaratuak.', # MODIF
	'texte_documents_joints_2' => 'Konfigurazio honek ez du galarazten irudien zuzeneko txertatzea artikuluetan.', # MODIF
	'titre_documents_joints' => 'Erantsitako dokumentuak',
	'tout_dossier_upload' => 'Karpeta osoa @upload@',

	// U
	'upload_fichier_zip' => 'ZIP fitxategia',
	'upload_fichier_zip_texte' => 'Instalatzea proposatzen den fitxategia Zip fitxategi bat da.',
	'upload_fichier_zip_texte2' => 'Fitxategi hau izan ahal da:',
	'upload_limit' => 'Fitxategi hauhandiegia da zerbitzarirako; baimendutako gehienezko tamainia upload-ean@max@-koa da.',
	'upload_zip_decompacter' => 'deskonprimituta eta gunean instalatutadaukan elementu bakoitza. Gunean instalatu egingo diren fitxategiak dira:',
	'upload_zip_telquel' => 'Besterik gabe instalatuta, Zip fitxategi bezala;'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_eu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=eu
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'Dokumentu bat erantsi',
	'bouton_ajouter_image' => 'Irudi bat erantsi',
	'bouton_ajouter_image_document' => 'Irudi bat edo dokumentu bat erantsi',

	// D
	'double_clic_inserer_doc' => 'klik bikoitzaren bidez lasterbidea testoan txertatzen ahal duzu',

	// E
	'entree_dimensions' => 'Dimentsioak',
	'entree_titre_document' => 'Agiriaren izenburua :',
	'entree_titre_image' => 'Irudiaren izenburua :',

	// I
	'image_tourner_180' => '180 graduko errotazioa',
	'image_tourner_droite' => '90 graduko errotazioa eskuinera',
	'image_tourner_gauche' => '90 graduko errotazioa ezkerrera',
	'info_document' => 'Dokumentua',
	'info_document_indisponible' => 'Dokumentu hau ez da erabilgarria',
	'info_documents' => 'Dokumentuak',
	'info_inclusion_directe' => 'Zuzeneko inklusioa:',
	'info_inclusion_vignette' => 'Miniaturaren inklusioa :',
	'info_installer_tous_documents' => 'Dokumentu guztiak instalatu',
	'info_logo_max_taille' => 'Logoek @maxi@ baino gutxiago neurtu behar dure derrigorrez (artxiboak @actuel@ neurtzen du).',
	'info_portfolio' => 'Album-orrialdea',
	'info_referencer_doc_distant' => 'Dokumentu bat interneten erreferentziatu :',
	'info_telecharger' => 'Zure ordenagailutik igo :',
	'item_autoriser_selectionner_date_en_ligne' => 'dokumentu bakotxaren data aldatzea baimendu',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Dokumentuen data da gunean noiz gehituak izan diren data',

	// T
	'texte_documents_joints' => 'Dokumentuak(fitxategi bulegotikak, irudiak, multimedia, etab.) artikuluetara eta/edo ataletara gehitzea baimendu ahal duzu. Gero fitxategi hauek artikuluan erreferientziatuak izaten ahalko dira, edo bananduta bistaratuak.', # MODIF
	'texte_documents_joints_2' => 'Konfigurazio honek ez du galarazten irudien zuzeneko txertatzea artikuluetan.', # MODIF
	'titre_documents_joints' => 'Erantsitako dokumentuak',
	'tout_dossier_upload' => 'Karpeta osoa @upload@',

	// U
	'upload_fichier_zip' => 'ZIP fitxategia',
	'upload_fichier_zip_texte' => 'Instalatzea proposatzen den fitxategia Zip fitxategi bat da.',
	'upload_fichier_zip_texte2' => 'Fitxategi hau izan ahal da:',
	'upload_limit' => 'Fitxategi hauhandiegia da zerbitzarirako; baimendutako gehienezko tamainia upload-ean@max@-koa da.',
	'upload_zip_decompacter' => 'deskonprimituta eta gunean instalatutadaukan elementu bakoitza. Gunean instalatu egingo diren fitxategiak dira:',
	'upload_zip_telquel' => 'Besterik gabe instalatuta, Zip fitxategi bezala;',
];
